import java.io.File;

import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

import com.saxonica.config.EnterpriseConfiguration;

import net.sf.saxon.lib.FeatureKeys;

public class ValidatorTestProgram {
    public static void main(String... args) {
        if (args.length < 3) {
            System.out.println("Usage:");
            System.out.println("Provide path to Saxon license file as the first parameter");
            System.out.println("Provide path to schema file as the second parameter");
            System.out.println("Provide path to xml file as the third parameter");
            System.exit(1);
        }
        
        String licensePath = args[0];
        String schemaFile = args[1];
        String xmlFile = args[2];
        
        try {
            SchemaFactory schemaFactory = getSchemaFactory(licensePath);
            Schema schema = schemaFactory.newSchema(new File(schemaFile));
            
            Validator validator = schema.newValidator();
            validator.setErrorHandler(new CustomHandler());
            validator.validate(new StreamSource(xmlFile));
        } catch (SAXParseException spe) {
            System.out.println("Parse exception occurred:");
            System.out.println(spe);
        } catch (Exception e) {
            System.out.println("Exception occurred:");
            System.out.println(e);
        }
    }
    
    private static SchemaFactory getSchemaFactory(String licenseFilePath) {
        EnterpriseConfiguration conf = new EnterpriseConfiguration();
        conf.setConfigurationProperty(FeatureKeys.LICENSE_FILE_LOCATION, licenseFilePath);
        return new com.saxonica.ee.jaxp.SchemaFactoryImpl(conf);
    }
}

class CustomHandler implements ErrorHandler {
    
    @Override
    public void warning(SAXParseException exception) throws SAXException {
        System.out.println("Warning: " + exception);
    }
    
    @Override
    public void error(SAXParseException exception) throws SAXException {
        System.out.println("Error: " + exception);
    }
    
    @Override
    public void fatalError(SAXParseException exception) throws SAXException {
        System.out.println("Fatal error: " + exception);
    }
}
